<?php
// Create database connection using config file
include_once("config.php");

// Tentukan jumlah data per halaman
$batas = 10;
$halaman = isset($_GET['halaman']) ? (int)$_GET['halaman'] : 1;
$halaman_awal = ($halaman > 1) ? ($halaman * $batas) - $batas : 0;

// Ambil nilai pencarian jika ada
$search_query = isset($_GET['search']) ? $_GET['search'] : "";

// Query untuk jumlah total data dengan pencarian
if ($search_query != "") {
    $stmt = $mysqli->prepare("SELECT * FROM data_member WHERE username LIKE ? OR jenis_cheat LIKE ?");
    $search_term = "%" . $search_query . "%";
    $stmt->bind_param("ss", $search_term, $search_term);
    $stmt->execute();
    $result = $stmt->get_result();
} else {
    $stmt = $mysqli->prepare("SELECT * FROM data_member");
    $stmt->execute();
    $result = $stmt->get_result();
}

$jumlah_data = $result->num_rows;
$total_halaman = ceil($jumlah_data / $batas);

// Query data dengan limit untuk halaman dan pencarian
if ($search_query != "") {
    $stmt = $mysqli->prepare("SELECT * FROM data_member WHERE username LIKE ? OR jenis_cheat LIKE ? LIMIT ?, ?");
    $stmt->bind_param("ssii", $search_term, $search_term, $halaman_awal, $batas);
} else {
    $stmt = $mysqli->prepare("SELECT * FROM data_member LIMIT ?, ?");
    $stmt->bind_param("ii", $halaman_awal, $batas);
}

$stmt->execute();
$data_member = $stmt->get_result();

$nomor = $halaman_awal + 1;
?>
<!DOCTYPE html>
<html lang="en">
<head>    
    <title>Homepage</title>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="icon" type="image/png" href="images/icons/favicon.ico"/>
    <link rel="stylesheet" type="text/css" href="vendor/bootstrap/css/bootstrap.min.css">
    <link rel="stylesheet" type="text/css" href="fonts/font-awesome-4.7.0/css/font-awesome.min.css">
    <link rel="stylesheet" type="text/css" href="vendor/animate/animate.css">
    <link rel="stylesheet" type="text/css" href="vendor/select2/select2.min.css">
    <link rel="stylesheet" type="text/css" href="vendor/perfect-scrollbar/perfect-scrollbar.css">
    <link rel="stylesheet" type="text/css" href="./css/util.css">
    <link rel="stylesheet" type="text/css" href="./css/main.css">
    <link rel="stylesheet" type="text/css" href="https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/4.1.3/css/bootstrap.min.css">
</head>
<body>
<div class="limiter">
    <div class="container-table100">
        <div class="wrap-table100">
            <div class="table100">
                <a href="add.php">Add New User</a><br/><br/>
                
                <!-- Form Pencarian -->
                <form method="GET" action="" class="form-inline mb-3">
                    <input type="text" name="search" class="form-control mr-2" placeholder="Cari data..." value="<?php echo htmlspecialchars($search_query); ?>">
                    <button type="submit" class="btn btn-primary">Cari</button>
                </form>
                
                <table>
                    <thead>
                        <tr class="table100-head">
                            <th class="column2">No.</th>
                            <th class="column2">Username</th>
                            <th class="column2">Jenis Cheat</th>
                            <th class="column2">Update</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php 
                        while ($user_data = $data_member->fetch_assoc()) {
                            echo "<tr>";
                            echo "<td>" . $nomor++ . "</td>";
                            echo "<td>" . htmlspecialchars($user_data['username']) . "</td>";
                            echo "<td>" . htmlspecialchars($user_data['jenis_cheat']) . "</td>";
                            echo "<td><a href='edit.php?id=" . htmlspecialchars($user_data['id_member']) . "'><i class='fa fa-edit'></i></a> | 
                                <a href='delete.php?id=" . htmlspecialchars($user_data['id_member']) . "' id='delete' class='btn btn-danger btn-sm'><i class='fa fa-trash'></i></a></td>";
                            echo "</tr>";
                        }
                        ?>
                    </tbody>
                </table>
                <br>
                <nav>
                    <ul class="pagination justify-content-center">
                        <?php
                        $jumlah_tampilkan = 1; // Jumlah halaman di sekitar halaman aktif
                        $start_page = max(1, $halaman - $jumlah_tampilkan);
                        $end_page = min($total_halaman, $halaman + $jumlah_tampilkan);

                        // Tombol "Previous"
                        if ($halaman > 1) {
                            echo "<li class='page-item'><a class='page-link' href='?halaman=" . ($halaman - 1) . "&search=" . urlencode($search_query) . "'>&lt; PREV</a></li>";
                        }

                        // Halaman pertama jika tidak dalam range
                        if ($start_page > 1) {
                            echo "<li class='page-item'><a class='page-link' href='?halaman=1&search=" . urlencode($search_query) . "'>1</a></li>";
                            if ($start_page > 2) {
                                echo "<li class='page-item disabled'><a class='page-link'>...</a></li>";
                            }
                        }

                        // Halaman di sekitar halaman aktif
                        for ($i = $start_page; $i <= $end_page; $i++) {
                            if ($i != $halaman) {
                                echo "<li class='page-item'><a class='page-link' href='?halaman=$i&search=" . urlencode($search_query) . "'>$i</a></li>";
                            } else {
                                echo "<li class='page-item active'><a class='page-link' href='#'>$i</a></li>";
                            }
                        }

                        // Halaman terakhir jika tidak dalam range
                        if ($end_page < $total_halaman) {
                            if ($end_page < $total_halaman - 1) {
                                echo "<li class='page-item disabled'><a class='page-link'>...</a></li>";
                            }
                            echo "<li class='page-item'><a class='page-link' href='?halaman=$total_halaman&search=" . urlencode($search_query) . "'>$total_halaman</a></li>";
                        }

                        // Tombol "Next"
                        if ($halaman < $total_halaman) {
                            echo "<li class='page-item'><a class='page-link' href='?halaman=" . ($halaman + 1) . "&search=" . urlencode($search_query) . "'>NEXT &gt;</a></li>";
                        }
                        ?>
                    </ul>
                </nav>
            </div>
        </div>
    </div>
</div>
<script src="vendor/jquery/jquery-3.2.1.min.js"></script>
<script src="vendor/bootstrap/js/popper.js"></script>
<script src="vendor/bootstrap/js/bootstrap.min.js"></script>
<script src="vendor/select2/select2.min.js"></script>
<script src="js/main.js"></script>
</body>
</html>
